@@ -21,6 +21,16 @@ class {class_name}Converter(Converter):
         """Converts an instance of {class_name} and return a Reference or Schema."""
 '''
 
+MISSING_CONFIG_CONTEXT = """
+You're not allowed to call this function outside the use_documentation_config context manager.
+Please call the function in the following manner:
+
+>>> builder = OpenAPIBuilder()
+>>> config = Documentation()  # retrieved from the @add_documentation decorator.
+>>> with builder.use_documentation_config():
+>>>     builder.your_function()
+"""
+
 
 class OpenApiException(Exception):
     """Base Exception."""
@@ -34,3 +44,13 @@ class MissingConverter(OpenApiException):
         super().__init__(
             MISSING_PROCESSOR_MESSAGE.format(class_name=to_camelcase(class_name))
         )
+
+
+class MissingConfigContext(OpenApiException):
+    """Missing config context.
+
+    The function must be called inside the 'use_documentation_config' context manager.
+    """
+
+    def __init__(self):
+        super().__init__(MISSING_CONFIG_CONTEXT)
